==> xoops-2.4.5.tbz: www/xoops/htdocs/language/english/countries.php <==
<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code
 which is considered copyrighted (c) material of the original comment or credit authors.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 *  Xoops Language
 *
 * @copyright       The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license         http://www.fsf.org/copyleft/gpl.html GNU public license
 * @package         kernel
 * @subpackage      Xoops Countries Language
 * @since           2.0.0
 * @author          Kazumi Ono <onokazu@xoops.org>
 * @version         $Id: countries.php 3284 2009-06-12 13:30:57Z trabis $
 */
defined('XOOPS_ROOT_PATH') or die('Restricted access');

// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
/* 
 * ISO 3166 Maintenance agency (ISO 3166/MA) - ISO's focal point for country codes 
 * Website: http://www.iso.org/iso/country_codes.htm
 *
 */

define('_COUNTRY_AD', 'Andorra');
define('_COUNTRY_AE', 'United Arab Emirates');
define('_COUNTRY_AF', 'Afghanistan');
define('_COUNTRY_AG', 'Antigua and Barbuda');
define('_COUNTRY_AI', 'Anguilla');
define('_COUNTRY_AL', 'Albania');
define('_COUNTRY_AM', 'Armenia');
define('_COUNTRY_AN', 'Netherlands Antilles');
define('_COUNTRY_AO', 'Angola');
define('_COUNTRY_AQ', 'Antarctica');
define('_COUNTRY_AR', 'Argentina');
define('_COUNTRY_AS', 'American Samoa');
define('_COUNTRY_AT', 'Austria');
define('_COUNTRY_AU', 'Australia');
define('_COUNTRY_AW', 'Aruba');
define('_COUNTRY_AX', 'Åland Islands');
define('_COUNTRY_AZ', 'Azerbaijan');
define('_COUNTRY_BA', 'Bosnia and Herzegovina');
define('_COUNTRY_BB', 'Barbados');
define('_COUNTRY_BD', 'Bangladesh');
define('_COUNTRY_BE', 'Belgium');
define('_COUNTRY_BF', 'Burkina Faso');
define('_COUNTRY_BG', 'Bulgaria');
define('_COUNTRY_BH', 'Bahrain');
define('_COUNTRY_BI', 'Burundi');
define('_COUNTRY_BJ', 'Benin');
define('_COUNTRY_BL', 'Saint Barthélemy');
define('_COUNTRY_BM', 'Bermuda');
define('_COUNTRY_BN', 'Brunei Darussalam');
define('_COUNTRY_BO', 'Bolivia');
define('_COUNTRY_BR', 'Brazil');
define('_COUNTRY_BS', 'Bahamas');
define('_COUNTRY_BT', 'Bhutan');
define('_COUNTRY_BV', 'Bouvet Island');
define('_COUNTRY_BW', 'Botswana');
define('_COUNTRY_BY', 'Belarus');
define('_COUNTRY_BZ', 'Belize');
define('_COUNTRY_CA', 'Canada');
define('_COUNTRY_CC', 'Cocos (Keeling) Islands');
define('_COUNTRY_CD', 'Congo (Dem. Rep.)');
define('_COUNTRY_CF', 'Central African Republic');
define('_COUNTRY_CG', 'Congo');
define('_COUNTRY_CH', 'Switzerland');
define('_COUNTRY_CI', 'Côte D\'Ivoire');
define('_COUNTRY_CK', 'Cook Islands');
define('_COUNTRY_CL', 'Chile');
define('_COUNTRY_CM', 'Cameroon');
define('_COUNTRY_CN', 'China');
define('_COUNTRY_CO', 'Colombia');
define('_COUNTRY_CR', 'Costa Rica');
define('_COUNTRY_CS', 'Czechoslovakia (former)');	//  Not listed in ISO 3166
define('_COUNTRY_CU', 'Cuba');
define('_COUNTRY_CV', 'Cape Verde');
define('_COUNTRY_CX', 'Christmas Island');
define('_COUNTRY_CY', 'Cyprus');
define('_COUNTRY_CZ', 'Czech Republic');
define('_COUNTRY_DE', 'Germany');
define('_COUNTRY_DJ', 'Djibouti');
define('_COUNTRY_DK', 'Denmark');
define('_COUNTRY_DM', 'Dominica');
define('_COUNTRY_DO', 'Dominican Republic');
define('_COUNTRY_DZ', 'Algeria');
define('_COUNTRY_EC', 'Ecuador');
define('_COUNTRY_EE', 'Estonia');
define('_COUNTRY_EG', 'Egypt');
define('_COUNTRY_EH', 'Western Sahara');
define('_COUNTRY_ER', 'Eritrea');
define('_COUNTRY_ES', 'Spain');
define('_COUNTRY_ET', 'Ethiopia');
define('_COUNTRY_FI', 'Finland');
define('_COUNTRY_FJ', 'Fiji');
define('_COUNTRY_FK', 'Falkland Islands (Malvinas)');
define('_COUNTRY_FM', 'Micronesia');
define('_COUNTRY_FO', 'Faroe Islands');
define('_COUNTRY_FR', 'France');
define('_COUNTRY_FX', 'France, Metropolitan');	//  Not listed in ISO 3166
define('_COUNTRY_GA', 'Gabon');
define('_COUNTRY_GB', 'Great Britain (UK)');
define('_COUNTRY_GD', 'Grenada');
define('_COUNTRY_GE', 'Georgia');
define('_COUNTRY_GF', 'French Guiana');
define('_COUNTRY_GG', 'Guernsey');
define('_COUNTRY_GH', 'Ghana');
define('_COUNTRY_GI', 'Gibraltar');
define('_COUNTRY_GL', 'Greenland');
define('_COUNTRY_GM', 'Gambia');
define('_COUNTRY_GN', 'Guinea');
define('_COUNTRY_GP', 'Guadeloupe');
define('_COUNTRY_GQ', 'Equatorial Guinea');
define('_COUNTRY_GR', 'Greece');
define('_COUNTRY_GS', 'S. Georgia and S. Sandwich Isls.');
define('_COUNTRY_GT', 'Guatemala');
define('_COUNTRY_GU', 'Guam');
define('_COUNTRY_GW', 'Guinea-Bissau');
define('_COUNTRY_GY', 'Guyana');
define('_COUNTRY_HK', 'Hong Kong');
define('_COUNTRY_HM', 'Heard and McDonald Islands');
define('_COUNTRY_HN', 'Honduras');
define('_COUNTRY_HR', 'Croatia');
define('_COUNTRY_HT', 'Haiti');
define('_COUNTRY_HU', 'Hungary');
define('_COUNTRY_ID', 'Indonesia');
define('_COUNTRY_IE', 'Ireland');
define('_COUNTRY_IL', 'Israel');
define('_COUNTRY_IM', 'Isle of Man');
define('_COUNTRY_IN', 'India');
define('_COUNTRY_IO', 'British Indian Ocean Territory');
define('_COUNTRY_IQ', 'Iraq');
define('_COUNTRY_IR', 'Iran');
define('_COUNTRY_IS', 'Iceland');
define('_COUNTRY_IT', 'Italy');
define('_COUNTRY_JM', 'Jamaica');
define('_COUNTRY_JO', 'Jordan');
define('_COUNTRY_JP', 'Japan');
define('_COUNTRY_KE', 'Kenya');
define('_COUNTRY_KG', 'Kyrgyzstan');
define('_COUNTRY_KH', 'Cambodia');
define('_COUNTRY_KI', 'Kiribati');
define('_COUNTRY_KM', 'Comoros');
define('_COUNTRY_KN', 'Saint Kitts and Nevis');
define('_COUNTRY_KP', 'Korea (North)');
define('_COUNTRY_KR', 'Korea (South)');
define('_COUNTRY_KW', 'Kuwait');
define('_COUNTRY_KY', 'Cayman Islands');
define('_COUNTRY_KZ', 'Kazakhstan');
define('_COUNTRY_LA', 'Laos');
define('_COUNTRY_LB', 'Lebanon');
define('_COUNTRY_LC', 'Saint Lucia');
define('_COUNTRY_LI', 'Liechtenstein');
define('_COUNTRY_LK', 'Sri Lanka');
define('_COUNTRY_LR', 'Liberia');
define('_COUNTRY_LS', 'Lesotho');
define('_COUNTRY_LT', 'Lithuania');
define('_COUNTRY_LU', 'Luxembourg');
define('_COUNTRY_LV', 'Latvia');
define('_COUNTRY_LY', 'Libya');
define('_COUNTRY_MA', 'Morocco');
define('_COUNTRY_MC', 'Monaco');
define('_COUNTRY_MD', 'Moldova');
define('_COUNTRY_ME', 'Montenegro');
define('_COUNTRY_MF', 'Saint Martin');
define('_COUNTRY_MG', 'Madagascar');
define('_COUNTRY_MH', 'Marshall Islands');
define('_COUNTRY_MK', 'Macedonia');
define('_COUNTRY_ML', 'Mali');
define('_COUNTRY_MM', 'Myanmar');
define('_COUNTRY_MN', 'Mongolia');
define('_COUNTRY_MO', 'Macao');
define('_COUNTRY_MP', 'Northern Mariana Islands');
define('_COUNTRY_MQ', 'Martinique');
define('_COUNTRY_MR', 'Mauritania');
define('_COUNTRY_MS', 'Montserrat');
define('_COUNTRY_MT', 'Malta');
define('_COUNTRY_MU', 'Mauritius');
define('_COUNTRY_MV', 'Maldives');
define('_COUNTRY_MW', 'Malawi');
define('_COUNTRY_MX', 'Mexico');
define('_COUNTRY_MY', 'Malaysia');
define('_COUNTRY_MZ', 'Mozambique');
define('_COUNTRY_NA', 'Namibia');
define('_COUNTRY_NC', 'New Caledonia');
define('_COUNTRY_NE', 'Niger');
define('_COUNTRY_NF', 'Norfolk Island');
define('_COUNTRY_NG', 'Nigeria');
define('_COUNTRY_NI', 'Nicaragua');
define('_COUNTRY_NL', 'Netherlands');
define('_COUNTRY_NO', 'Norway');
define('_COUNTRY_NP', 'Nepal');
define('_COUNTRY_NR', 'Nauru');
define('_COUNTRY_NT', 'Neutral Zone');
define('_COUNTRY_NU', 'Niue');
define('_COUNTRY_NZ', 'New Zealand');
define('_COUNTRY_OM', 'Oman');
define('_COUNTRY_PA', 'Panama');
define('_COUNTRY_PE', 'Peru');
define('_COUNTRY_PF', 'French Polynesia');
define('_COUNTRY_PG', 'Papua New Guinea');
define('_COUNTRY_PH', 'Philippines');
define('_COUNTRY_PK', 'Pakistan');
define('_COUNTRY_PL', 'Poland');
define('_COUNTRY_PM', 'St. Pierre and Miquelon');
define('_COUNTRY_PN', 'Pitcairn');
define('_COUNTRY_PR', 'Puerto Rico');
define('_COUNTRY_PS', 'Palestine');
define('_COUNTRY_PT', 'Portugal');
define('_COUNTRY_PW', 'Palau');
define('_COUNTRY_PY', 'Paraguay');
define('_COUNTRY_QA', 'Qatar');
define('_COUNTRY_RE', 'Reunion');
define('_COUNTRY_RO', 'Romania');
define('_COUNTRY_RS', 'Serbia');
define('_COUNTRY_RU', 'Russian Federation');
define('_COUNTRY_RW', 'Rwanda');
define('_COUNTRY_SA', 'Saudi Arabia');
define('_COUNTRY_SB', 'Solomon Islands');
define('_COUNTRY_SC', 'Seychelles');
define('_COUNTRY_SD', 'Sudan');
define('_COUNTRY_SE', 'Sweden');
define('_COUNTRY_SG', 'Singapore');
define('_COUNTRY_SH', 'St. Helena');
define('_COUNTRY_SI', 'Slovenia');
define('_COUNTRY_SJ', 'Svalbard and Jan Mayen Islands');
define('_COUNTRY_SK', 'Slovakia');
define('_COUNTRY_SL', 'Sierra Leone');
define('_COUNTRY_SM', 'San Marino');
define('_COUNTRY_SN', 'Senegal');
define('_COUNTRY_SO', 'Somalia');
define('_COUNTRY_SR', 'Suriname');
define('_COUNTRY_ST', 'Sao Tome and Principe');
define('_COUNTRY_SU', 'USSR (former)');	//  Not listed in ISO 3166
define('_COUNTRY_SV', 'El Salvador');
define('_COUNTRY_SY', 'Syria');
define('_COUNTRY_SZ', 'Swaziland');
define('_COUNTRY_TC', 'Turks and Caicos Islands');
define('_COUNTRY_TD', 'Chad');
define('_COUNTRY_TF', 'French Southern Territories');
define('_COUNTRY_TG', 'Togo');
define('_COUNTRY_TH', 'Thailand');
define('_COUNTRY_TJ', 'Tajikistan');
define('_COUNTRY_TK', 'Tokelau');
define('_COUNTRY_TL', 'Timor-Leste');
define('_COUNTRY_TM', 'Turkmenistan');
define('_COUNTRY_TN', 'Tunisia');
define('_COUNTRY_TO', 'Tonga');
define('_COUNTRY_TP', 'East Timor');	//  Not listed in ISO 3166
define('_COUNTRY_TR', 'Turkey');
define('_COUNTRY_TT', 'Trinidad and Tobago');
define('_COUNTRY_TV', 'Tuvalu');
define('_COUNTRY_TW', 'Taiwan');
define('_COUNTRY_TZ', 'Tanzania');
define('_COUNTRY_UA', 'Ukraine');
define('_COUNTRY_UG', 'Uganda');
define('_COUNTRY_UK', 'United Kingdom');
define('_COUNTRY_UM', 'US Minor Outlying Islands');
define('_COUNTRY_US', 'United States');
define('_COUNTRY_UY', 'Uruguay');
define('_COUNTRY_UZ', 'Uzbekistan');
define('_COUNTRY_VA', 'Vatican City State (Holy See)');
define('_COUNTRY_VC', 'Saint Vincent and the Grenadines');
define('_COUNTRY_VE', 'Venezuela');
define('_COUNTRY_VG', 'Virgin Islands (British)');
define('_COUNTRY_VI', 'Virgin Islands (US)');
define('_COUNTRY_VN', 'Viet Nam');
define('_COUNTRY_VU', 'Vanuatu');
define('_COUNTRY_WF', 'Wallis and Futuna Islands');
define('_COUNTRY_WS', 'Samoa');
define('_COUNTRY_YE', 'Yemen');
define('_COUNTRY_YT', 'Mayotte');
define('_COUNTRY_YU', 'Yugoslavia');	//  Not listed in ISO 3166
define('_COUNTRY_ZA', 'South Africa');
define('_COUNTRY_ZM', 'Zambia');
define('_COUNTRY_ZR', 'Zaire');	//  Not listed in ISO 3166
define('_COUNTRY_ZW', 'Zimbabwe');
?>

==> xoops-2.5.5.tbz: www/xoops/htdocs/language/english/countries.php <==
<?php
// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
/* 
 * ISO 3166 Maintenance agency (ISO 3166/MA) - ISO's focal point for country codes 
 * Website: http://www.iso.org/iso/country_codes.htm
 *
 */

define('_COUNTRY_AD', 'Andorra');
define('_COUNTRY_AE', 'United Arab Emirates');
define('_COUNTRY_AF', 'Afghanistan');
define('_COUNTRY_AG', 'Antigua and Barbuda');
define('_COUNTRY_AI', 'Anguilla');
define('_COUNTRY_AL', 'Albania');
define('_COUNTRY_AM', 'Armenia');
define('_COUNTRY_AN', 'Netherlands Antilles');
define('_COUNTRY_AO', 'Angola');
define('_COUNTRY_AQ', 'Antarctica');
define('_COUNTRY_AR', 'Argentina');
define('_COUNTRY_AS', 'American Samoa');
define('_COUNTRY_AT', 'Austria');
define('_COUNTRY_AU', 'Australia');
define('_COUNTRY_AW', 'Aruba');
define('_COUNTRY_AX', 'Åland Islands');
define('_COUNTRY_AZ', 'Azerbaijan');
define('_COUNTRY_BA', 'Bosnia and Herzegovina');
define('_COUNTRY_BB', 'Barbados');
define('_COUNTRY_BD', 'Bangladesh');
define('_COUNTRY_BE', 'Belgium');
define('_COUNTRY_BF', 'Burkina Faso');
define('_COUNTRY_BG', 'Bulgaria');
define('_COUNTRY_BH', 'Bahrain');
define('_COUNTRY_BI', 'Burundi');
define('_COUNTRY_BJ', 'Benin');
define('_COUNTRY_BL', 'Saint Barthélemy');
define('_COUNTRY_BM', 'Bermuda');
define('_COUNTRY_BN', 'Brunei Darussalam');
define('_COUNTRY_BO', 'Bolivia');
define('_COUNTRY_BR', 'Brazil');
define('_COUNTRY_BS', 'Bahamas');
define('_COUNTRY_BT', 'Bhutan');
define('_COUNTRY_BV', 'Bouvet Island');
define('_COUNTRY_BW', 'Botswana');
define('_COUNTRY_BY', 'Belarus');
define('_COUNTRY_BZ', 'Belize');
define('_COUNTRY_CA', 'Canada');
define('_COUNTRY_CC', 'Cocos (Keeling) Islands');
define('_COUNTRY_CD', 'Congo (Dem. Rep.)');
define('_COUNTRY_CF', 'Central African Republic');
define('_COUNTRY_CG', 'Congo');
define('_COUNTRY_CH', 'Switzerland');
define('_COUNTRY_CI', "Côte d'Ivoire"); 
define('_COUNTRY_CK', 'Cook Islands');
define('_COUNTRY_CL', 'Chile');
define('_COUNTRY_CM', 'Cameroon');
define('_COUNTRY_CN', 'China');
define('_COUNTRY_CO', 'Colombia');
define('_COUNTRY_CR', 'Costa Rica');
define('_COUNTRY_CS', 'Serbia & Montenegro (former)');	//  Not listed in ISO 3166
define('_COUNTRY_CU', 'Cuba');
define('_COUNTRY_CV', 'Cape Verde');
define('_COUNTRY_CX', 'Christmas Island');
define('_COUNTRY_CY', 'Cyprus');
define('_COUNTRY_CZ', 'Czech Republic');
define('_COUNTRY_DE', 'Germany');
define('_COUNTRY_DJ', 'Djibouti');
define('_COUNTRY_DK', 'Denmark');
define('_COUNTRY_DM', 'Dominica');
define('_COUNTRY_DO', 'Dominican Republic');
define('_COUNTRY_DZ', 'Algeria');
define('_COUNTRY_EC', 'Ecuador');
define('_COUNTRY_EE', 'Estonia');
define('_COUNTRY_EG', 'Egypt');
define('_COUNTRY_EH', 'Western Sahara');
define('_COUNTRY_ER', 'Eritrea');
define('_COUNTRY_ES', 'Spain');
define('_COUNTRY_ET', 'Ethiopia');
define('_COUNTRY_FI', 'Finland');
define('_COUNTRY_FJ', 'Fiji');
define('_COUNTRY_FK', 'Falkland Islands (Malvinas)');
define('_COUNTRY_FM', 'Micronesia');
define('_COUNTRY_FO', 'Faroe Islands');
define('_COUNTRY_FR', 'France');
define('_COUNTRY_FX', 'France, Metropolitan');	//  Not listed in ISO 3166
define('_COUNTRY_GA', 'Gabon');
define('_COUNTRY_GB', 'Great Britain (UK)');
define('_COUNTRY_GD', 'Grenada');
define('_COUNTRY_GE', 'Georgia');
define('_COUNTRY_GF', 'French Guiana');
define('_COUNTRY_GG', 'Guernsey');
define('_COUNTRY_GH', 'Ghana');
define('_COUNTRY_GI', 'Gibraltar');
define('_COUNTRY_GL', 'Greenland');
define('_COUNTRY_GM', 'Gambia');
define('_COUNTRY_GN', 'Guinea');
define('_COUNTRY_GP', 'Guadeloupe');
define('_COUNTRY_GQ', 'Equatorial Guinea');
define('_COUNTRY_GR', 'Greece');
define('_COUNTRY_GS', 'S. Georgia and S. Sandwich Isls.');
define('_COUNTRY_GT', 'Guatemala');
define('_COUNTRY_GU', 'Guam');
define('_COUNTRY_GW', 'Guinea-Bissau');
define('_COUNTRY_GY', 'Guyana');
define('_COUNTRY_HK', 'Hong Kong');
define('_COUNTRY_HM', 'Heard and McDonald Islands');
define('_COUNTRY_HN', 'Honduras');
define('_COUNTRY_HR', 'Croatia');
define('_COUNTRY_HT', 'Haiti');
define('_COUNTRY_HU', 'Hungary');
define('_COUNTRY_ID', 'Indonesia');
define('_COUNTRY_IE', 'Ireland');
define('_COUNTRY_IL', 'Israel');
define('_COUNTRY_IM', 'Isle of Man');
define('_COUNTRY_IN', 'India');
define('_COUNTRY_IO', 'British Indian Ocean Territory');
define('_COUNTRY_IQ', 'Iraq');
define('_COUNTRY_IR', 'Iran');
define('_COUNTRY_IS', 'Iceland');
define('_COUNTRY_IT', 'Italy');
define('_COUNTRY_JM', 'Jamaica');
define('_COUNTRY_JO', 'Jordan');
define('_COUNTRY_JP', 'Japan');
define('_COUNTRY_KE', 'Kenya');
define('_COUNTRY_KG', 'Kyrgyzstan');
define('_COUNTRY_KH', 'Cambodia');
define('_COUNTRY_KI', 'Kiribati');
define('_COUNTRY_KM', 'Comoros');
define('_COUNTRY_KN', 'Saint Kitts and Nevis');
define('_COUNTRY_KP', 'Korea (North)');
define('_COUNTRY_KR', 'Korea (South)');
define('_COUNTRY_KW', 'Kuwait');
define('_COUNTRY_KY', 'Cayman Islands');
define('_COUNTRY_KZ', 'Kazakhstan');
define('_COUNTRY_LA', 'Laos');
define('_COUNTRY_LB', 'Lebanon');
define('_COUNTRY_LC', 'Saint Lucia');
define('_COUNTRY_LI', 'Liechtenstein');
define('_COUNTRY_LK', 'Sri Lanka');
define('_COUNTRY_LR', 'Liberia');
define('_COUNTRY_LS', 'Lesotho');
define('_COUNTRY_LT', 'Lithuania');
define('_COUNTRY_LU', 'Luxembourg');
define('_COUNTRY_LV', 'Latvia');
define('_COUNTRY_LY', 'Libya');
define('_COUNTRY_MA', 'Morocco');
define('_COUNTRY_MC', 'Monaco');
define('_COUNTRY_MD', 'Moldova');
define('_COUNTRY_ME', 'Montenegro');
define('_COUNTRY_MF', 'Saint Martin');
define('_COUNTRY_MG', 'Madagascar');
define('_COUNTRY_MH', 'Marshall Islands');
define('_COUNTRY_MK', 'Macedonia'); //FYROM
define('_COUNTRY_ML', 'Mali');
define('_COUNTRY_MM', 'Myanmar');
define('_COUNTRY_MN', 'Mongolia');
define('_COUNTRY_MO', 'Macao');
define('_COUNTRY_MP', 'Northern Mariana Islands');
define('_COUNTRY_MQ', 'Martinique');
define('_COUNTRY_MR', 'Mauritania');
define('_COUNTRY_MS', 'Montserrat');
define('_COUNTRY_MT', 'Malta');
define('_COUNTRY_MU', 'Mauritius');
define('_COUNTRY_MV', 'Maldives');
define('_COUNTRY_MW', 'Malawi');
define('_COUNTRY_MX', 'Mexico');
define('_COUNTRY_MY', 'Malaysia');
define('_COUNTRY_MZ', 'Mozambique');
define('_COUNTRY_NA', 'Namibia');
define('_COUNTRY_NC', 'New Caledonia');
define('_COUNTRY_NE', 'Niger');
define('_COUNTRY_NF', 'Norfolk Island');
define('_COUNTRY_NG', 'Nigeria');
define('_COUNTRY_NI', 'Nicaragua');
define('_COUNTRY_NL', 'Netherlands');
define('_COUNTRY_NO', 'Norway');
define('_COUNTRY_NP', 'Nepal');
define('_COUNTRY_NR', 'Nauru');
define('_COUNTRY_NT', 'Neutral Zone');
define('_COUNTRY_NU', 'Niue');
define('_COUNTRY_NZ', 'New Zealand');
define('_COUNTRY_OM', 'Oman');
define('_COUNTRY_PA', 'Panama');
define('_COUNTRY_PE', 'Peru');
define('_COUNTRY_PF', 'French Polynesia');
define('_COUNTRY_PG', 'Papua New Guinea');
define('_COUNTRY_PH', 'Philippines');
define('_COUNTRY_PK', 'Pakistan');
define('_COUNTRY_PL', 'Poland');
define('_COUNTRY_PM', 'St. Pierre and Miquelon');
define('_COUNTRY_PN', 'Pitcairn');
define('_COUNTRY_PR', 'Puerto Rico');
define('_COUNTRY_PS', 'Palestine Territory (Occupied)');
define('_COUNTRY_PT', 'Portugal');
define('_COUNTRY_PW', 'Palau');
define('_COUNTRY_PY', 'Paraguay');
define('_COUNTRY_QA', 'Qatar');
define('_COUNTRY_RE', 'Reunion');
define('_COUNTRY_RO', 'Romania');
define('_COUNTRY_RS', 'Serbia');
define('_COUNTRY_RU', 'Russian Federation');
define('_COUNTRY_RW', 'Rwanda');
define('_COUNTRY_SA', 'Saudi Arabia');
define('_COUNTRY_SB', 'Solomon Islands');
define('_COUNTRY_SC', 'Seychelles');
define('_COUNTRY_SD', 'Sudan');
define('_COUNTRY_SE', 'Sweden');
define('_COUNTRY_SG', 'Singapore');
define('_COUNTRY_SH', 'St. Helena');
define('_COUNTRY_SI', 'Slovenia');
define('_COUNTRY_SJ', 'Svalbard and Jan Mayen Islands');
define('_COUNTRY_SK', 'Slovakia');
define('_COUNTRY_SL', 'Sierra Leone');
define('_COUNTRY_SM', 'San Marino');
define('_COUNTRY_SN', 'Senegal');
define('_COUNTRY_SO', 'Somalia');
define('_COUNTRY_SR', 'Suriname');
define('_COUNTRY_ST', 'Sao Tome and Principe');
define('_COUNTRY_SU', 'USSR (former)');	//  Not listed in ISO 3166
define('_COUNTRY_SV', 'El Salvador');
define('_COUNTRY_SY', 'Syria');
define('_COUNTRY_SZ', 'Swaziland');
define('_COUNTRY_TC', 'Turks and Caicos Islands');
define('_COUNTRY_TD', 'Chad');
define('_COUNTRY_TF', 'French Southern Territories');
define('_COUNTRY_TG', 'Togo');
define('_COUNTRY_TH', 'Thailand');
define('_COUNTRY_TJ', 'Tajikistan');
define('_COUNTRY_TK', 'Tokelau');
define('_COUNTRY_TL', 'Timor-Leste');
define('_COUNTRY_TM', 'Turkmenistan');
define('_COUNTRY_TN', 'Tunisia');
define('_COUNTRY_TO', 'Tonga');
define('_COUNTRY_TP', 'East Timor');	//  Not listed in ISO 3166, changed to TL
define('_COUNTRY_TR', 'Turkey');
define('_COUNTRY_TT', 'Trinidad and Tobago');
define('_COUNTRY_TV', 'Tuvalu');
define('_COUNTRY_TW', 'Taiwan');
define('_COUNTRY_TZ', 'Tanzania');
define('_COUNTRY_UA', 'Ukraine');
define('_COUNTRY_UG', 'Uganda');
//define('_COUNTRY_UK', 'United Kingdom'); //  Not listed in ISO 3166
define('_COUNTRY_UM', 'US Minor Outlying Islands');
define('_COUNTRY_US', 'United States');
define('_COUNTRY_UY', 'Uruguay');
define('_COUNTRY_UZ', 'Uzbekistan');
define('_COUNTRY_VA', 'Vatican City State (Holy See)');
define('_COUNTRY_VC', 'Saint Vincent and the Grenadines');
define('_COUNTRY_VE', 'Venezuela');
define('_COUNTRY_VG', 'Virgin Islands (British)');
define('_COUNTRY_VI', 'Virgin Islands (US)');
define('_COUNTRY_VN', 'Viet Nam');
define('_COUNTRY_VU', 'Vanuatu');
define('_COUNTRY_WF', 'Wallis and Futuna Islands');
define('_COUNTRY_WS', 'Samoa');
define('_COUNTRY_YE', 'Yemen');
define('_COUNTRY_YT', 'Mayotte');
define('_COUNTRY_YU', 'Yugoslavia (former)');	//  Not listed in ISO 3166
define('_COUNTRY_ZA', 'South Africa');
define('_COUNTRY_ZM', 'Zambia');
define('_COUNTRY_ZR', 'Zaire');	//  Not listed in ISO 3166
define('_COUNTRY_ZW', 'Zimbabwe');
?>
